@@ -22,11 +22,12 @@ https://github.com/kellyjonbrazil/jc/tree/master/docs
 
 ### Specific Version
 
-Replace `<full_version_number>` - e.g. `1.17.7`:
-
 `https://github.com/kellyjonbrazil/jc/tree/v<full_version_number>/docs`
 
-Specific versions can also be selected by tag in the branch dropdown menu.
+> Replace `<full_version_number>` - e.g. `1.18.0`:
+
+Specific versions can also be selected by tag in the Github branch dropdown
+menu.
 
 ## Usage Example
 
@@ -67,13 +68,16 @@ built-in parsers and local plugin parsers.
 
 ### parser_info
 
-    parser_info(parser_module_name: str) -> dict
+    parser_info(
+        parser_module_name: str,
+        documentation: bool = False
+    ) -> dict
 
 Get the metadata for a particular parser.
 
 ### all_parser_info
 
-    all_parser_info() -> list[dict]
+    all_parser_info(documentation: bool = False) -> list[dict]
 
 Get the metadata for all parsers.
 
@@ -86,14 +90,14 @@ its module name.
 
 ### parser_mod_list
 
-    parser_mod_list() -> list
+    parser_mod_list() -> list[str]
 
 Get a list of all available parser module names to be used in
 `parse()`, `parser_info()`, and `get_help()`.
 
 ### plugin_parser_mod_list
 
-    plugin_parser_mod_list() -> list
+    plugin_parser_mod_list() -> list[str]
 
 Get a list of plugin parser module names to be used in
 `parse()`, `parser_info()`, and `get_help()`. This list is a subset of
@@ -101,7 +105,7 @@ Get a list of plugin parser module names to be used in
 
 ### standard_parser_mod_list
 
-    standard_parser_mod_list() -> list
+    standard_parser_mod_list() -> list[str]
 
 Get a list of standard parser module names to be used in
 `parse()`, `parser_info()`, and `get_help()`. This list is a subset of
@@ -109,7 +113,7 @@ Get a list of standard parser module names to be used in
 
 ### streaming_parser_mod_list
 
-    streaming_parser_mod_list() -> list
+    streaming_parser_mod_list() -> list[str]
 
 Get a list of streaming parser module names to be used in
 `parse()`, `parser_info()`, and `get_help()`. This list is a subset of
