@@ -9,10 +9,13 @@ import textwrap
 import signal
 import shlex
 import subprocess
+from typing import List, Dict
 from .lib import (__version__, parser_info, all_parser_info, parsers,
                   _get_parser, _parser_is_streaming, standard_parser_mod_list,
                   plugin_parser_mod_list, streaming_parser_mod_list)
 from . import utils
+from .cli_data import long_options_map, new_pygments_colors, old_pygments_colors
+from .shell_completions import bash_completion, zsh_completion
 from . import tracebackplus
 from .exceptions import LibraryNotInstalled, ParseError
 
@@ -45,43 +48,9 @@ class info():
 # startswith is sufficient and avoids potential exceptions from split and int.
 if PYGMENTS_INSTALLED:
     if pygments.__version__.startswith('2.3.'):
-        PYGMENT_COLOR = {
-            'black': '#ansiblack',
-            'red': '#ansidarkred',
-            'green': '#ansidarkgreen',
-            'yellow': '#ansibrown',
-            'blue': '#ansidarkblue',
-            'magenta': '#ansipurple',
-            'cyan': '#ansiteal',
-            'gray': '#ansilightgray',
-            'brightblack': '#ansidarkgray',
-            'brightred': '#ansired',
-            'brightgreen': '#ansigreen',
-            'brightyellow': '#ansiyellow',
-            'brightblue': '#ansiblue',
-            'brightmagenta': '#ansifuchsia',
-            'brightcyan': '#ansiturquoise',
-            'white': '#ansiwhite',
-        }
+        PYGMENT_COLOR = old_pygments_colors
     else:
-        PYGMENT_COLOR = {
-            'black': 'ansiblack',
-            'red': 'ansired',
-            'green': 'ansigreen',
-            'yellow': 'ansiyellow',
-            'blue': 'ansiblue',
-            'magenta': 'ansimagenta',
-            'cyan': 'ansicyan',
-            'gray': 'ansigray',
-            'brightblack': 'ansibrightblack',
-            'brightred': 'ansibrightred',
-            'brightgreen': 'ansibrightgreen',
-            'brightyellow': 'ansibrightyellow',
-            'brightblue': 'ansibrightblue',
-            'brightmagenta': 'ansibrightmagenta',
-            'brightcyan': 'ansibrightcyan',
-            'white': 'ansiwhite',
-        }
+        PYGMENT_COLOR = new_pygments_colors
 
 
 def set_env_colors(env_colors=None):
@@ -166,6 +135,22 @@ def parsers_text(indent=0, pad=0):
     return ptext
 
 
+def options_text(indent=0, pad=0):
+    """Return the argument and description information from each option"""
+    otext = ''
+    padding_char = ' '
+    for option in long_options_map:
+        o_short = '-' + long_options_map[option][0]
+        o_desc = long_options_map[option][1]
+        o_combined = o_short + ',  ' + option
+        padding = pad - len(o_combined)
+        indent_text = padding_char * indent
+        padding_text = padding_char * padding
+        otext += indent_text + o_combined + padding_text + o_desc + '\n'
+
+    return otext
+
+
 def about_jc():
     """Return jc info and the contents of each parser.info as a dictionary"""
     return {
@@ -189,43 +174,35 @@ def about_jc():
 
 def helptext():
     """Return the help text with the list of parsers"""
-    parsers_string = parsers_text(indent=12, pad=17)
+    parsers_string = parsers_text(indent=4, pad=20)
+    options_string = options_text(indent=4, pad=20)
 
     helptext_string = f'''\
-    jc converts the output of many commands and file-types to JSON
+jc converts the output of many commands and file-types to JSON or YAML
 
-    Usage:  COMMAND | jc PARSER [OPTIONS]
+Usage:
+    COMMAND | jc PARSER [OPTIONS]
 
-            or magic syntax:
+    or magic syntax:
 
-            jc [OPTIONS] COMMAND
+    jc [OPTIONS] COMMAND
 
-    Parsers:
+Parsers:
 {parsers_string}
-    Options:
-            -a    about jc
-            -C    force color output even when using pipes (overrides -m)
-            -d    debug (-dd for verbose debug)
-            -h    help (-h --parser_name for parser documentation)
-            -m    monochrome output
-            -p    pretty print output
-            -q    quiet - suppress parser warnings (-qq to ignore streaming errors)
-            -r    raw JSON output
-            -u    unbuffer output
-            -v    version info
-            -y    YAML output
+Options:
+{options_string}
+Examples:
+    Standard Syntax:
+        $ dig www.google.com | jc --dig --pretty
 
-    Examples:
-            Standard Syntax:
-                $ dig www.google.com | jc --dig -p
+    Magic Syntax:
+        $ jc --pretty dig www.google.com
 
-            Magic Syntax:
-                $ jc -p dig www.google.com
+    Parser Documentation:
+        $ jc --help --dig
+'''
 
-            Parser Documentation:
-                $ jc -h --dig
-    '''
-    return textwrap.dedent(helptext_string)
+    return helptext_string
 
 
 def help_doc(options):
@@ -285,7 +262,7 @@ def yaml_out(data, pretty=False, env_colors=None, mono=False, piped_out=False, a
         # ruamel.yaml versions prior to 0.17.0 the use of __file__ in the
         # plugin code is incompatible with the pyoxidizer packager
         YAML.official_plug_ins = lambda a: []
-        yaml=YAML()
+        yaml = YAML()
         yaml.default_flow_style = False
         yaml.explicit_start = True
         yaml.allow_unicode = not ascii_only
@@ -381,7 +358,7 @@ def magic_parser(args):
         jc_options    (list)  list of jc options
     """
     # bail immediately if there are no args or a parser is defined
-    if len(args) <= 1 or args[1].startswith('--'):
+    if len(args) <= 1 or (args[1].startswith('--') and args[1] not in long_options_map):
         return False, None, None, []
 
     args_given = args[1:]
@@ -389,6 +366,12 @@ def magic_parser(args):
 
     # find the options
     for arg in list(args_given):
+        # long option found - populate option list
+        if arg in long_options_map:
+            options.extend(long_options_map[arg][0])
+            args_given.pop(0)
+            continue
+
         # parser found - use standard syntax
         if arg.startswith('--'):
             return False, None, None, []
@@ -483,6 +466,9 @@ def main():
     # find options if magic_parser did not find a command
     if not valid_command:
         for opt in sys.argv:
+            if opt in long_options_map:
+                options.extend(long_options_map[opt][0])
+
             if opt.startswith('-') and not opt.startswith('--'):
                 options.extend(opt[1:])
 
@@ -499,6 +485,8 @@ def main():
     unbuffer = 'u' in options
     version_info = 'v' in options
     yaml_out = 'y' in options
+    bash_comp = 'B' in options
+    zsh_comp = 'Z' in options
 
     if verbose_debug:
         tracebackplus.enable(context=11)
@@ -523,6 +511,14 @@ def main():
         utils._safe_print(versiontext())
         sys.exit(0)
 
+    if bash_comp:
+        utils._safe_print(bash_completion())
+        sys.exit(0)
+
+    if zsh_comp:
+        utils._safe_print(zsh_completion())
+        sys.exit(0)
+
     # if magic syntax used, try to run the command and error if it's not found, etc.
     magic_stdout, magic_stderr, magic_exit_code = None, None, 0
     if run_command:
@@ -592,7 +588,7 @@ def main():
     try:
         # differentiate between regular and streaming parsers
 
-        # streaming
+        # streaming (only supports UTF-8 string data for now)
         if _parser_is_streaming(parser):
             result = parser.parse(sys.stdin,
                                   raw=raw,
@@ -609,9 +605,17 @@ def main():
 
             sys.exit(combined_exit_code(magic_exit_code, 0))
 
-        # regular
+        # regular (supports binary and UTF-8 string data)
         else:
-            data = magic_stdout or sys.stdin.read()
+            data = magic_stdout or sys.stdin.buffer.read()
+
+            # convert to UTF-8, if possible. Otherwise, leave as bytes
+            try:
+                if isinstance(data, bytes):
+                    data = data.decode('utf-8')
+            except UnicodeDecodeError:
+                pass
+
             result = parser.parse(data,
                                   raw=raw,
                                   quiet=quiet)
