@@ -1,6 +1,6 @@
 """jc - JSON Convert `ifconfig` command output parser
 
-Note: No `ifconfig` options are supported.
+> Note: No `ifconfig` options are supported.
 
 Usage (cli):
 
