@@ -15,11 +15,6 @@ Usage (module):
     import jc
     result = jc.parse('iptables', iptables_command_output)
 
-    or
-
-    import jc.parsers.iptables
-    result = jc.parsers.iptables.parse(iptables_command_output)
-
 Schema:
 
     [
@@ -168,7 +163,7 @@ import jc.utils
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.7'
+    version = '1.8'
     description = '`iptables` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -269,7 +264,6 @@ def parse(data, raw=False, quiet=False):
                 continue
 
             elif line.startswith('target') or line.find('pkts') == 1 or line.startswith('num'):
-                headers = []
                 headers = [h for h in ' '.join(line.lower().strip().split()).split() if h]
                 headers.append("options")
 
