@@ -4,8 +4,8 @@ Supports `ping` and `ping6` output.
 
 Usage (cli):
 
-    Note:  Use the ping `-c` (count) option, otherwise data will not be
-           piped to `jc`.
+> Note:  Use the ping `-c` (count) option, otherwise data will not be
+> piped to `jc`.
 
     $ ping -c 3 1.2.3.4 | jc --ping
 
@@ -18,11 +18,6 @@ Usage (module):
     import jc
     result = jc.parse('ping', ping_command_output)
 
-    or
-
-    import jc.parsers.ping
-    result = jc.parsers.ping.parse(ping_command_output)
-
 Schema:
 
     {
