@@ -1,20 +1,20 @@
 """jc - JSON Convert `ping` command output streaming parser
 
-> This streaming parser outputs JSON Lines (cli) or returns a Generator
-  iterator of Dictionaries (module)
+> This streaming parser outputs JSON Lines (cli) or returns an Iterable of
+> Dictionaries (module)
 
 Supports `ping` and `ping6` output.
 
 Usage (cli):
 
-    $ ping | jc --ping-s
+    $ ping 1.2.3.4 | jc --ping-s
 
 > Note: When piping `jc` converted `ping` output to other processes it may
-  appear the output is hanging due to the OS pipe buffers. This is because
-  `ping` output is too small to quickly fill up the buffer. Use the `-u`
-  option to unbuffer the `jc` output if you would like immediate output.
-  See the [readme](https://github.com/kellyjonbrazil/jc/tree/master#unbuffering-output)
-  for more information.
+> appear the output is hanging due to the OS pipe buffers. This is because
+> `ping` output is too small to quickly fill up the buffer. Use the `-u`
+> option to unbuffer the `jc` output if you would like immediate output.
+> See the [readme](https://github.com/kellyjonbrazil/jc/tree/master#unbuffering-output)
+> for more information.
 
 Usage (module):
 
@@ -465,7 +465,7 @@ def _linux_parse(line, s):
 @add_jc_meta
 def parse(data, raw=False, quiet=False, ignore_exceptions=False):
     """
-    Main text parsing generator function. Returns an iterator object.
+    Main text parsing generator function. Returns an iterable object.
 
     Parameters:
 
@@ -476,13 +476,9 @@ def parse(data, raw=False, quiet=False, ignore_exceptions=False):
         quiet:             (boolean)   suppress warning messages if True
         ignore_exceptions: (boolean)   ignore parsing exceptions if True
 
-    Yields:
-
-        Dictionary. Raw or processed structured data.
-
     Returns:
 
-        Iterator object (generator)
+        Iterable of Dictionaries
     """
     jc.utils.compatibility(__name__, info.compatible, quiet)
     streaming_input_type_check(data)
