@@ -114,7 +114,8 @@ def is_compatible(compatible: List) -> bool:
 def compatibility(mod_name: str, compatible: List, quiet: bool = False) -> None:
     """
     Checks for the parser's compatibility with the running OS platform and
-    prints a warning message to `STDERR` if not compatible and quiet=False.
+    prints a warning message to `STDERR` if not compatible and
+    `quiet=False.`
 
     Parameters:
 
@@ -139,21 +140,27 @@ def compatibility(mod_name: str, compatible: List, quiet: bool = False) -> None:
         ])
 
 
-def has_data(data: str) -> bool:
+def has_data(data: Union[str, bytes]) -> bool:
     """
-    Checks if the input contains data. If there are any non-whitespace
-    characters then return True, else return False.
+    Checks if the string input contains data. If there are any
+    non-whitespace characters then return `True`, else return `False`.
+
+    For bytes, returns True if there is any data.
 
     Parameters:
 
-        data:        (string) input to check whether it contains data
+        data:        (string, bytes) input to check whether it contains data
 
     Returns:
 
         Boolean      True if input string (data) contains non-whitespace
-                     characters, otherwise False
+                     characters, otherwise False. For bytes data, returns
+                     True if there is any data, otherwise False.
     """
-    return bool(data and not data.isspace())
+    if isinstance(data, str):
+        return bool(data and not data.isspace())
+
+    return bool(data)
 
 
 def convert_to_int(value: Union[str, float]) -> Optional[int]:
